package com.diagbot.web;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.SearchEvaluatorDTO;
import com.diagbot.entity.Evaluator;
import com.diagbot.facade.EvaluatorFacade;
import com.diagbot.vo.AddEvaluatorVO;
import com.diagbot.vo.SearchEvaluatorVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 评估用户结果表 前端控制器
 * </p>
 *
 * @author gaodm
 * @since 2019-05-30
 */
@RestController
@RequestMapping("/evaluator")
@SuppressWarnings("unchecked")
@Api(value = "体质评估API", tags = { "体质评估API" })
public class EvaluatorController {
    @Autowired
    private EvaluatorFacade evaluatorFacade;

    @ApiOperation(value = "体质评估——添加[by:gaodm]",
            notes = "name: 姓名,必填<br>" +
                    "phone: 手机号,必填<br>" +
                    "sex: 性别(1：男 2：女),必填<br>" +
                    "age: 年龄,必填<br>" +
                    "mildValue: 平和体质转化分,必填<br>" +
                    "faintValue: 气虚体质转化分,必填<br>" +
                    "wetValue: 湿滞体质转化分,必填<br>" +
                    "heartValue: 心肝火旺体质转化分,必填<br>" +
                    "stagnantValue: 积滞体质转化分,必填<br>" +
                    "exceptValue: 异禀体质转化分,必填")
    @PostMapping("/addEvaluator")
    @SysLogger("addEvaluator")
    @Transactional
    public RespDTO<Boolean> addEvaluator(@RequestBody @Valid AddEvaluatorVO addDeptInfoVO){
        return RespDTO.onSuc(evaluatorFacade.addEvaluator(addDeptInfoVO));
    }

    @ApiOperation(value = "体质评估——获取体质评估分页信息[by:gaodm]",
            notes = "name: 姓名<br>" +
                    "phone: 手机号<br>" +
                    "sex: 性别(1：男 2：女)")
    @PostMapping("/getEvaluatorPage")
    @SysLogger("getEvaluatorPage")
    public RespDTO<IPage<SearchEvaluatorDTO>> getEvaluatorPage(@RequestBody SearchEvaluatorVO searchEvaluatorVO){
        return RespDTO.onSuc(evaluatorFacade.getEvaluatorPage(searchEvaluatorVO));
    }


    /**
     * 体质规则计算,测试使用
     *
     * @param evaluator 输入参数
     * @return 返回计算结果值
     */
    @ApiOperation(value = "体质规则计算，测试使用", notes = "体质规则计算，测试使用")
    @PostMapping("/cal2")
    @SysLogger("cal2")
    public RespDTO<String> cal2(@RequestBody Evaluator evaluator) {
        evaluatorFacade.cal(evaluator);
        return RespDTO.onSuc(evaluator.getPhysicalRes());
    }
}
